<h1 style="
text-align: center;
font-family: Serif;
font-size: 6vh;
">
<span style="
color: darkgoldenrod;
letter-spacing: -6px;
margin-right: -2.2%;"
>Django</span>
<span style="
color: darkgoldenrod;
letter-spacing: -3px;"
>Start</span>
Automate Script ✨
</h1>

<div style="
text-align: center;
background: rgba(131,131,131,0.17);
padding: 10px;
border-radius: 5px;
width: 650px;
margin: 0 auto
">
    Django automate start project and create app
    This script saves time for you to start a new Django project.
    It creates the project and creates the first app
    and then updates the project settings file and
    also updates the project urls file and then creates a views
    and configures the application urls file and
    also creates the index.html
</div>
<div style="text-align: center; margin-top: 10px">
<img src="https://img.shields.io/github/stars/islam-kamel/django-start?style=social" alt="Repo Stars">
<img src="https://img.shields.io/badge/platform-Windows%20%7C%20Linux-green" alt="Platform Support">
<img src="https://img.shields.io/badge/Latest%20Version-1.0.0--beta.2-green" alt="Latest Version">
<img src="https://img.shields.io/github/downloads/islam-kamel/django-start/total", alt="Downloads Count">
<img src="https://img.shields.io/github/release-date-pre/islam-kamel/django-start", alt="GitHub (Pre-)Release Date">
</div>

---
## Welcome to contribute ❤

```shell
pip install pyinstaller | pyinstaller --noconfirm --onefile --console --add-data <requests_package_path> --add-data <djstartlib>  "django-start.py"
```
